@@ -402,7 +402,7 @@ class SubprocessMngr(object):
            # Launch without console on MSWindows
            #
            startupinfo = subprocess.STARTUPINFO()
-           startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
+           #startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
            self.process = subprocess.Popen(cmd.strip(), stdout=stdout, stderr=stderr, startupinfo=startupinfo, env=env, bufsize=bufsize, shell=shell)
         elif False:   # subprocess.jython:
            #
